// ----------------------------------------------------------------------------
//
//	htmlstrings.cxx
//
// Copyright (C) 2008
//		Dave Freese, W1HKJ
//
// This file is part of fldigi.
//
// Fldigi is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Fldigi is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with fldigi.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------

#include <config.h>

#include "dialogs/guide.cxx"

const char* szAbout =
"<!DOCTYPE html PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">\n\
<html>\n\
<head>\n\
  <title>About</title>\n\
</head>\n\
<BODY BGCOLOR=FFFFCO TEXT=101010>\n\
<font size=\"0\" face=\"Verdana, Arial, Helvetica\">\n\
<CENTER>\n\
<H3><I>Fldigi " PACKAGE_VERSION "</I></H3>\n\
<br>\n\
Fast and Light Digital modem program\n\
</CENTER>\n\
<P>\n\
Copyright \251 2008-2012 " FLDIGI_AUTHORS ".\n\
<P>\n\
Distributed under the GNU General Public License version 3 or later.<br>\n\
This is free software: you are free to change and redistribute it.<br>\n\
There is NO WARRANTY, to the extent permitted by law.\n\
<H4>Programmers:</H4>\n\
&nbsp; &nbsp; &nbsp;Dave Freese, W1HKJ<br>\n\
&nbsp; &nbsp; &nbsp;Stelios Bounanos, M0GLD<br>\n\
&nbsp; &nbsp; &nbsp;Rem\355 Chateauneu, F4ECW<br>\n\
&nbsp; &nbsp; &nbsp;John Douyere, VK2ETA<br>\n\
&nbsp; &nbsp; &nbsp;Stefan Fendt, DL1SMF<br>\n\
&nbsp; &nbsp; &nbsp;Leigh Klotz, WA5ZNU<br>\n\
&nbsp; &nbsp; &nbsp;John Phelps, KL4YFD<br>\n\
&nbsp; &nbsp; &nbsp;Andrej Lajovic, S57LN\n\
<H4>Localization:</H4>\n\
&nbsp; &nbsp; &nbsp;German:  Marc Richter,        DF2MR<br>\n\
&nbsp; &nbsp; &nbsp;French:  St\351phane Fillod,     F8CFE<br>\n\
&nbsp; &nbsp; &nbsp;Italian: Pierfrancesco Caci,  IK5PVX<br>\n\
&nbsp; &nbsp; &nbsp;Polish:  Roman Bagiński,      SP4JEU<br>\n\
&nbsp; &nbsp; &nbsp;Spanish: Pavel Milanes Costa, CO7WT<br>\n\
<H4>Beginners' Guide:</H4>\n\
&nbsp; &nbsp; &nbsp;Murray Greenman, ZL1BPU<br>\n\
</body>\n\
</html>\n\
";

